"use client";

import { SimpleGrid, Icon, useColorModeValue, Box, Text } from "@chakra-ui/react";
import { useGeneral } from "@/contexts/GeneralContext";
import { setStorage } from "@/utils/navigation";
import { useRouter } from "next/navigation";
import { useSession } from "next-auth/react";

const ProjectsGrid = () => {
  const { newProjects, saveProjectId } = useGeneral();
  const router = useRouter();
  const { data: session, update } = useSession();
  const boxBg = useColorModeValue("secondaryGray.300", "whiteAlpha.100");
  const brandColor = useColorModeValue("brand.500", "white");

  const handleSetProject = async (value: string | number) => {
    setStorage('x-project-id', value?.toString());
    saveProjectId(value?.toString());
    session.currentProjectId = value?.toString();
    await update({
      ...session,
      currentProjectId: value,
    });
    router.push('/admin/dashboard')

  }

  return (
    <SimpleGrid columns={{ base: 1, md: 2, lg: 4, "2xl": 4 }} gap="20px" mb="20px">
      {newProjects.map((project, index) => (
        <Box
          key={index}
          bg={boxBg}
          display="flex" alignItems="center" justifyContent="space-between" rounded="12px" padding={4} cursor="pointer"
          onClick={() => handleSetProject(project?.id)}
        >
          <Text color={brandColor} fontSize={24} fontWeight={500}>{project?.name ?? ''}</Text>
          <Text color={brandColor} fontSize={24} fontWeight={500}>{project?.id ?? ''}</Text>
        </Box>
      ))}
    </SimpleGrid>
  );
};

export default ProjectsGrid;
